## escapework/manager-medias

Módulo de mídias para integração com o escapework/manager.

## Instalação

Adicione os seguintes itens no seu `composer.json` e execute o comando um `composer update`:

```json
{
    "require": {
        "escapework/manager-medias": "0.9.*"
    },

    "repositories": [
        {
            "type": "git",
            "url": "git@bitbucket.org:escapecria/manager-medias.git"
        }
    ]
}
```

### ServiceProvider

Adicione a linha `'EscapeWork\Manager\Medias\Providers\MediaServiceProvider'` no array de Service Providers no arquivo `app/config/app.php`.

### Configurações

Execute o comando abaixo para configurar o pacote:

```sh
$ php artisan manager:configure
```

### Seeds

Para não precisar criar manualmente os tamanhos em todos os servidores (local, produção, staging, etc), o ideal é você criar um seeder para isto. E o pacote possui um helper para ajudar você:

```php
    $data = array(
        'model'       => 'EscapeWork\Manager\News\Models\News',
        'model_title' => 'title',
        'model_route' => 'manager.noticias.index',
        'page_title'  => 'Notíciass',
    );

    $sizes = array(
        array(
            'prefix' => 'vga-',
            'width'  => 640,
            'height' => 480,
            'resize' => 1,
        ),
    );

    MediaModel::createForSeeder($data, $sizes);
```

Simplesmente declare dois arrays (`$data` e `$sizes`), e passe para o método `MediaModel::createForSeeder`. Os tamanhos já existentes serão atualizados, e os não existentes serão criados.

### Recriando os tamanhos

Existe um comando que você pode executar toda vez que criar um novo tamanho, para redimensionar as imagens antigas.

```php
$ php artisan manager-medias:recreate-sizes
```

Toda vez que um novo tamanho é criado, é executada uma rotina onde todos os tamanhos do model em questão são recriados.

### Utilizando a classe `ImageUploader` para upload de imagens.

Para não precisarmos criar vários métodos que verificam formato da imagem, tamanho, formatação do nome, podemos utilizar a classe `ImageUploader`, ela possui todas essas verificações dentro dela.

No seu Controller onde será feito o upload você pode chamar um método que fará o upload (No exemplo foi criado o método `uploadLogo`, mas pode ser criado o nome que preferir) passando por parâmetro o `Input` com a imagem, como no exemplo:

```php
    $this->client->uploadLogo(Input::file('logo'));
```

Depois no seu Repository ou Model chame a classe `ImageUploader`.

```php
    use EscapeWork\Manager\Medias\Helpers\ImageUploader;
```

Então criamos um método que receba a imagem como o exemplo:

```php
     public function uploadLogo($logo)
    {
        $uploader = new ImageUploader(public_path().'/files/clients', 'Escape\Models\Client');

        if ($uploader->upload($logo, $this->model->exists, $this->model->logotipo)) {
            $this->model->logotipo = $uploader->filename;
        }
```
Onde `public_path().'/files/clients'` é a pasta onde as imagens serão salvas e `'Escape\Models\Client'`  é o seu Model.
**Obs:** Este Model precisa estar criado na tabela `media_models`.

No método upload `$uploader->upload($logo, $this->model->exists, $this->model->logotipo)` o parâmetro `$this->model->exists` e o parâmetro `$this->model->logotipo` verificam se já existe o model e uma imagem para ele, se existir ele retorna substituindo a imagem antiga pela imagem nova `$this->model->logotipo = $uploader->filename;`.

### Todo

* Testes unitários
