<?php namespace EscapeWork\Manager\Medias\Models;

use EscapeWork\LaravelHelpers\Eloquent;

class MediaModel extends Eloquent
{

    /**
     * Table
     */
    protected $table = 'media_models';

    /**
     * Regras para validação
     */
    public static $validationRules = array(
        'model' => array('required', 'unique:media_models,model,:id:'),
    );

    /**
     * Mensagens para validação
     */
    public static $validationMessages = array(
        'model.required' => 'O nome da tabela é obrigatório',
        'model.unique'   => 'O model digitado já existe',
    );

    /**
     * Fillable fields
     */
    protected $fillable = array(
        'id',
        'model',
        'model_title',
        'model_route',
        'page_title',
    );

    public function sizes()
    {
        return $this->hasMany('EscapeWork\Manager\Medias\Models\MediaModelSize', 'media_model_id');
    }

    public static function createForSeeder($data, $sizes)
    {
        if (! $mediaModel = static::where('model', '=', $data['model'])->first()) {
            $mediaModel = new static;
        }

        $mediaModel->fill($data);
        $mediaModel->save();

        foreach ($sizes as $size) {
            $mediaModelSize = MediaModelSize::where('media_model_id', '=', $mediaModel->id)
                                            ->where('prefix', '=', $size['prefix'])
                                            ->first();

            if (! $mediaModelSize) {
                $mediaModelSize = new MediaModelSize;
            }

            $mediaModelSize->fill(array_merge(
                $size,
                array('media_model_id' => $mediaModel->id)
            ));
            $mediaModelSize->save();
        }
    }
}
